"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = require("../logger");
const sns_mock_1 = require("../mocks/sns-mock");
const sns_helper_1 = require("../helpers/sns-helper");
const test_values_1 = require("./test-values");
const logger = new logger_1.Logger(logger_1.LogLevel.Off);
const mockerResolves = new sns_mock_1.SNSMock(false);
const snsHelperMockResolves = new sns_helper_1.SNSHelper(logger, mockerResolves.Mock);
const mockerRejects = new sns_mock_1.SNSMock(true);
const snsHelperMockRejects = new sns_helper_1.SNSHelper(logger, mockerRejects.Mock);
const TestValues = new test_values_1.TestValuesClass();
/**
 * Test the PublishAsync method
 */
describe(`${sns_helper_1.SNSHelper.name}.${snsHelperMockResolves.PublishAsync.name}`, () => {
    // set action for this method
    const action = `${sns_helper_1.SNSHelper.name}.${snsHelperMockResolves.PublishAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} topicArn`, () => {
        const actual = snsHelperMockResolves.PublishAsync(TestValues.EmptyString, TestValues.Subject, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} topicArn`);
    });
    test(`${TestValues.ThrowsOnEmpty} subject`, () => {
        const actual = snsHelperMockResolves.PublishAsync(TestValues.Arn, TestValues.EmptyString, TestValues.Body);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} subject`);
    });
    test(`${TestValues.ThrowsOnEmpty} message`, () => {
        const actual = snsHelperMockResolves.PublishAsync(TestValues.Arn, TestValues.Subject, TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} message`);
    });
    test(TestValues.InvalidTest, () => {
        const actual = snsHelperMockRejects.PublishAsync(TestValues.Arn, TestValues.Subject, TestValues.Body);
        return expect(actual).rejects.toThrow(TestValues.AWSError);
    });
    test(TestValues.ValidTest, () => {
        const actual = snsHelperMockResolves.PublishAsync(TestValues.Arn, TestValues.Subject, TestValues.Body);
        return expect(actual).resolves.toEqual(mockerResolves.PublishResponse);
    });
});
//# sourceMappingURL=sns.spec.js.map